<?php
ini_set('error_log', dirname(__FILE__) . '/error_log');
ini_set('display_errors', 'off');
ini_set('log_errors', 'on');
error_reporting(E_ALL);

error_log( time() . ': ' . __FILE__ . ' startup' . PHP_EOL, 3, dirname( __FILE__ ) . '/error_log' );

if (!empty($_GET['ping'])) {
	echo 'Pong';
	exit;
}

$restorer = new Restore($_POST);
$restorer->execute();

exit;
/**
 * Pre Installer Payload Script
 *
 * This is called via curl. The settings are passed in the headers and the process is run
 * on the remote server.
 *
 * @subpackage Lib.assets
 *
 * @copyright SimpleScripts.com, 8 May, 2012
 * @author
 **/

/**
 * Define DocBlock
 **/

class Restore {

/**
 * Debug Storage
 *
 * @var array $debug
 */
	public $debug = array();

/**
 * Settings
 *
 * @var array $settings
 */
	public $settings = array(
		'extract_package' => true,
		'backup_dir' => '.ss_backup',
		'restore_files' => '1',
	);

/**
 * Class Constructor
 *
 * The $_POST will be sent to this method and merged into the $settings defaults.
 *
 * @author
 **/
	public function __construct($settings = null) {
		if (!$settings) {
			return false;
		}
		$this->debug['setup'][] = 'Configuring settings.';
		$this->settings = array_merge($this->settings, $settings);
		$this->settings['os'] = strtolower(substr(PHP_OS, 0, 3));
		$this->settings['root_directory'] = dirname(__FILE__);

		//Make sure the backup directory exists on the users account. If it doesn't the restore prcess will fail
		if (!is_dir($this->settings['backup_dir'])) {
			$this->debug['extra'][] = 'Restore cannot be completed. It appears that the backup directory has been moved or deleted';
			$this->errorDie();
		}
	}

/**
 * Does stuff
 *
 * @return [type] [description]
 */
	public function execute() {
		//restore the files
		if ($this->settings['restore_files']) {
			$this->debug['process'][] = 'Restoring Files';
			$this->restoreFiles();
			$this->debug['process'][] = 'Restored Files Successfully';
		}

		//restore database
		if ($this->settings['restore_database']) {
			$this->debug['process'][] = 'Restoring Database';
			$this->restoreDatabase();
			$this->debug['process'][] = 'Restored Database Successfully';
		}

		//cleanup
		$this->restoreProcessCleanup();

		$this->debug['status'] = 'success';
		echo json_encode($this->debug);
	}

/**
 * Restore Files
 *
 * Restores user files from a previous backup
 * @return void
 * @author
 */
	public function restoreFiles() {
		$this->settings['path_to_file'] = realpath(dirname(__FILE__) . DIRECTORY_SEPARATOR . $this->settings['filename']);

		if (!file_exists($this->settings['path_to_file'])) {
			$this->debug['error'][] = "Backup file not found.";
			$this->errorDie();
		}

		if (!$this->settings['path_to_file']) {
			$this->debug['error'][] = 'Backup file not found in the backup dir';
			$this->errorDie();
		}

		//get backup file extension information
		$extinfo = pathinfo($this->settings['path_to_file']);
		$this->settings['file_ext'] = $extinfo['extension'];

		if ($this->settings['extract_package']) {
			$this->debug['process'][] = 'Extracting package';
			$this->extractPackage();
			$this->debug['process'][] = 'Package extracted successfully!';
		}
		return true;
	}

/**
 * Restore Database
 *
 * Restore the user database
 * @return void
 * @author
 */
	public function restoreDatabase() {
		$filename = dirname(__FILE__) . DIRECTORY_SEPARATOR . '.database_backup.sql';
		if (!$filename) {
			$this->debug['error'][] = 'Database Backup File Not Found';
			$this->errorDie();
		}

		$backupCommand = sprintf(
			'mysql --user=%s --host=%s -p %s -e "source %s"',
			escapeshellarg($this->settings['ss_dbuser']),
			escapeshellarg($this->settings['ss_dbhost']),
			escapeshellarg($this->settings['ss_dbname']),
			$filename
		);

		$inputToRestoreCommand = sprintf(
			"%s\n",
			$this->settings['ss_dbpass']
		);

		$this->debug['database_restore_command'] = $backupCommand;
		$this->debug['process'][] = 'Running DB restore command';
		$result = $this->runCommand($backupCommand, 600, $inputToRestoreCommand);

		// Fallback to legacy on failure
		if ($result === false) {
			$host = $this->settings['ss_dbhost'];
			$username = $this->settings['ss_dbuser'];
			$password = $this->settings['ss_dbpass'];
			$database = $this->settings['ss_dbname'];
			if (!mysql_connect($host, $username, $password)) {
				$this->debug['error'][] = 'Unable to connect to the database';
				$this->errorDie();
			}
			if (!mysql_select_db($database)) {
				$this->debug['error'][] = 'Unable to Select the database';
				$this->errorDie();
			}
			$query = '';
			$lines = file($filename);
			foreach ($lines as $line) {
				if (substr($line, 0, 2) == '--' || $line == '')
					continue;
				$query .= $line;
				if (substr(trim($line), -1, 1) == ';') {
					if (!mysql_query($query)) {
						$this->debug['error'][] = 'Unable to run the query';
						$this->errorDie();
					}
					$query = '';
				}
			}
		}

		return true;
	}

/**
 * Extract Package
 *
 * Extract the package to the path specified or the default if not specified.
 *
 * @return void
 **/
	public function extractPackage() {
		if ($this->settings['os'] == 'win') {
			$this->debug['process'][] = 'Manual Extracting';
			$this->manualExtract();
		} else {
			$this->debug['process'][] = 'Auto Extracting';
			$this->autoExtract();
		}
		return true;
	}

/**
 * Auto Extraction
 *
 * Passthru works so we can run a command on the server to extract the files.
 *
 * @return void
 **/
	public function autoExtract() {
		$options = null;
		if ($this->settings['file_ext'] == 'tar') {
			$options = 'xf';
		} elseif ($this->settings['file_ext'] == 'tgz') {
			$options = 'xzf';
		} else {
			$this->error['incompatibleExtension'] = 'extension not compatible with extraction process.';
			$this->error['extra'] = dirname(__FILE__) . DIRECTORY_SEPARATOR . $this->settings['filename'];
			$this->errorDie();
		}
		$command = 'tar --no-same-owner -' . $options . ' ' . escapeshellarg($this->settings['path_to_file']);
		$this->settings['extract_command'] = $command;
		$result = $this->runCommand($command);
		$this->settings['list'] = preg_split("/\n/", $results);
		return true;
	}

/**
 * Manual Extract
 *
 * Extraction for windows machines
 *
 * @return void
 **/
	public function manualExtract() {
		$filename = $this->settings['path_to_file'];
		$returnValue = array();
		// Convert from tgz to tar
		if ($this->settings['file_ext'] == 'tgz') {
			$ghandle = gzopen($filename, 'r');
			$filename .= '.gzconvert';
			$reghandle = fopen($filename, 'w');
			gzseek($ghandle, 0);
			while ($temp = gzread($ghandle, 1048576)) {
				fwrite($reghandle, $temp);
			}
			fclose($reghandle);
			gzclose($ghandle);
		}
		$tarfile = @fopen($filename, 'r');
		$thetar = @fopen($filename, 'r');
		$longlinkfound = false;
		while (!feof($tarfile)) {
			$readdata = fread($tarfile, 512);
			if (substr($readdata, 257, 5) == 'ustar') {
				$tfilename = substr($readdata, 0, 100);
				$permissions = substr($readdata, 100, 8);
				$tfilename = dirname(__FILE__) . '/' . trim($tfilename);
				$indicator = substr($readdata, 156, 1);
				if ($indicator == 2) {
					$linklocation = dirname(__FILE__) . '/' . substr($readdata, 157, 100);
				}
				$offset = ftell($tarfile);
				$filesize = octdec(substr($readdata, 124, 12));
				$directory = "";
				if ($indicator == 5) {
					// Directory
					$levels = explode("/", $tfilename);
					$thestring = "";
					foreach ($levels as $level) {
						if ($level == '.') {
							continue;
						}
						$thestring .= $level . "/";
						$this->mkdir($thestring, 0755, true);
					}
					continue;
				}
				if ($indicator == 2) {
					symlink($linklocation, $tfilename);
					continue;
				}
				if ($longlinkfound) {
					$tfilename = dirname(__FILE__) . '/' . $longlinkfound;
				}
				if ($tfilename == dirname(__FILE__) . '/' . '././@LongLink') {
					fseek($thetar, $offset);
					$data = @fread($thetar, $filesize);
					$longlinkfound = $data;
					continue;
				} elseif ($longlinkfound) {
					$longlinkfound = false;
				}
				// Extract the file contents from the archive
				$fh = @fopen($tfilename, 'wb');
				fseek($thetar, $offset);
				$data = @fread($thetar, $filesize);
				$st = @fwrite($fh, $data);
				@fclose($fh);

				// Set permissions (if needed)
				if ($this->settings['os'] != 'WIN') {
					@chmod($tfilename, 0 . octdec(substr($permissions, 3)));
				}
			}
		}
		@fclose($thetar);
		@fclose($tarfile);
		// Remove temporary conversion file
		unlink( $filename );
		return true;
	}

/**
 * mkdir replacement
 *
 * Recursive directory creation fails if at any point an
 * implicit is_dir fails when exploring the tree.  The problem
 * being, that is_dir sometimes fails on CIFS (Windows Samba
 * mounts) when there are a large number of inodes.  When that
 * returns false, mkdir tries to create that directory in the
 * path, but the mkdir also fails because the directory does
 * in fact exist.  chdir, stat, file_exists, etc., also all
 * fail.  But if you try to create a directory inside of the
 * unreadable directory it will succeed - so we need to find
 * our way past that if we can before reporting failure.
 *
 * @param  string $dir
 * @param  octet  $mode
 * @param  bool   $recursive
 * @return bool
 **/
	public function mkdir($dir, $mode = 0777, $recursive = true) {
		if (@mkdir( $dir, $mode, $recursive )) {
			return true;
		} else {
			// Looks like we failed.  Chances are the first place we
			// couldn't read was the site root itself, so try to make
			// the first directory under that as a starting point.

			// First, standardize paths.
			$root = implode( DIRECTORY_SEPARATOR, preg_split( '{[/\\\\]}', $this->settings['root_directory'] ) );
			$path = implode( DIRECTORY_SEPARATOR, preg_split( '{[/\\\\]}', $dir ) );

			// Find only those path elements which immediately follow
			// the root, and see if we can create that directory first.
			if (!strpos( $path, $root) === 0) {
				// Doesn't look like one is in the other, bail out.
				return false;
			}

			// Get the first path element following the site root.
			$pathParts = array_filter(
				preg_split(
					'{[/\\\\]}',
					substr( $path, strlen( $root ) )
				)
			);
			if (!$pathParts || !count( $pathParts)) {
				false;
			}

			$firstPath = $root . ( !preg_match( '{[/\\\\]$}', $root ) ? DIRECTORY_SEPARATOR : '' ) . array_shift( $pathParts );
			// This attempt must be false, or it will fail just like the
			// initial one above.
			if (@mkdir( $firstPath, $mode, false )) {
				if ($recursive) {
					if (count( $pathParts )) {
						// Should be OK to resume trying from here.
						return @mkdir( $path, $mode, $recursive );
					} else {
						// Created all there is to create, return true.
						return true;
					}
				} elseif (implode( '', $pathParts )) {
					// Gave us a recursive path but were told non-recursive?
					return false;
				} else {
					return true;
				}
			}
		}
		return false;
	}

/**
 * Run Command
 *
 * Run the specified command using proc_open to get and return the results.
 *
 * @param string $command The command to run on the server.
 * @return string $output The raw output of the command.
 **/
	public function runCommand($command = null, $ttl = 600, $input = '') {
		if (!$command) {
			return false;
		}

		$descriptorSpec = Array(
			Array('pipe', 'r'),
			Array('pipe', 'w'),
			Array('pipe', 'w')
		);

		$pipes = Array();
		$stdout = '';
		$stderr = '';

		$process = proc_open($command, $descriptorSpec, $pipes);

		if (!is_resource($process)) {
			$this->debug[] = 'Failed to open process for command ' . $command;
			return false;
		}

		// Keep reads from hanging
		stream_set_blocking($pipes[0], 0);
		stream_set_blocking($pipes[1], 0);
		stream_set_blocking($pipes[2], 0);

		$loops = 0;

		if ($input) {
			sleep(1);
			fwrite($pipes[0], $input);
		}

		while (1) {
			$loops += 1;

			// This used to be fancy with stream_select, but it turns out that
			// stream_select doesn't block even when I want it to.  :/
			sleep(1);

			while ($moreStdout = stream_get_contents($pipes[1])) {
				$stdout .= $moreStdout;
			}

			while ($moreStderr = stream_get_contents($pipes[2])) {
				$stderr .= $moreStderr;
			}

			$status = proc_get_status($process);

			if (!$status['running']) {
				break;
			}

			if ($loops > $ttl) {
				$this->debug[] = "terminating with 15 due to timeout at $loops loops";
				proc_terminate($process, 15);
				$status['exitcode'] = '15';
			}

			if ($loops > 5 + $ttl) {
				$this->debug[] = "terminating with 9 due to timeout at $loops loops";
				proc_terminate($process, 9);
				$status['exitcode'] = '9';
			}
		}

		$exitCode = $status['exitcode'];

		$this->debug[] = compact('command', 'stdout', 'stderr', 'exitCode', 'loops');

		if ($exitCode) {
			return false;
		}

		return $stdout;
	}

/**
 * Restore Process Cleanup
 *
 * Cleanup after the backup process is run. Nuke the db thats created in the install directory
 *
 * @return void
 * @author
 **/
	public function restoreProcessCleanup() {
		@unlink(dirname(__FILE__) . DIRECTORY_SEPARATOR . '.database_backup.sql');
		return true;
	}

/**
 * Error
 *
 * Call an error to pass back to the caller.
 *
 * @return void
 *
 **/
	public function errorDie() {
		$this->error['status'] = 'error';
		$this->error['debug'] = $this->debug;
		$this->error = json_encode($this->error);
		die($this->error);
	}

}
